## Added `meson.build` scanner
Allows the use of Meson introspect commands to run in the background
so Meson-ui can auto fill `Setup Activity` and `Introspect Activity`
with the correct values rather than assuming the values.
